====================================================================
Kane's Method, Lagrange's Method & Associated Functions (Docstrings)
====================================================================

Kane
====

.. automodule:: sympy.physics.mechanics.kane
   :members:


partial_velocity
================

.. automodule:: sympy.physics.mechanics.functions
   :members: partial_velocity

LagrangesMethod
===============

.. automodule:: sympy.physics.mechanics.lagrange
   :members:
